Struct NonUnicodeOsStr
Source pub struct NonUnicodeOsStr();
Available on crate feature raw_os_str only.
A container for platform strings containing no unicode characters.
Instances can only be constructed using Utf8Chunks.
Converts this representation back to a platform-native string, without
copying or encoding conversion.
Converts this representation into units of an unspecified
platform-specific encoding.
For more information, see OsUnit.
Converts this type into a shared reference of the (usually inferred) input type.
Formats the value using the given formatter.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more
Tests less than (for
self and
other) and is used by the
< operator.
Read more
Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more
Tests greater than (for
self and
other) and is used by the
>
operator.
Read more
Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more