Pattern

Trait Pattern 

pub trait Pattern: Sealed { }
Allows a type to be used for searching by RawOsStr and RawOsString.

This trait is very similar to str::pattern::Pattern, but its methods are private and it is implemented for different types.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Pattern for &str

Source

impl Pattern for char

Source

impl<'a> Pattern for &'a String

Implementors